==> admin-services-api-1.1-sources.jar: org/odpi/openmetadata/adminservices/rest/OMAGServerServiceType.java <==
/* SPDX-License-Identifier: Apache 2.0 */
/* Copyright Contributors to the ODPi Egeria project. */
package org.odpi.openmetadata.adminservices.rest;

/**
 * OMAGServerServiceType lists the different types of services supported by the OMAG Server
 */
public enum OMAGServerServiceType
{
    REPOSITORY_SERVICES  (0, "Repository Services", "The Open Metadata Repository Services (OMRS)."),
    ACCESS_SERVICES      (1, "Access Services",     "The Open Metadata Access Services (OMAS).");

    private static final long serialVersionUID = 1L;

    private int            typeCode;
    private String         typeName;
    private String         typeDescription;


    /**
     * Default Constructor
     *
     * @param typeCode ordinal for this enum
     * @param typeName symbolic name for this enum
     * @param typeDescription short description for this enum
     */
    OMAGServerServiceType(int     typeCode, String   typeName, String   typeDescription)
    {
        /*
         * Save the values supplied
         */
        this.typeCode = typeCode;
        this.typeName = typeName;
        this.typeDescription = typeDescription;
    }


    /**
     * Return the code for this enum instance
     *
     * @return int type code
     */
    public int getTypeCode()
    {
        return typeCode;
    }


    /**
     * Return the default name for this enum instance.
     *
     * @return String default name
     */
    public String getTypeName()
    {
        return typeName;
    }


    /**
     * Return the default description for the type for this enum instance.
     *
     * @return String default description
     */
    public String getTypeDescription()
    {
        return typeDescription;
    }
}

==> admin-services-api-1.4-sources.jar: org/odpi/openmetadata/adminservices/rest/OMAGServerServiceType.java <==
/* SPDX-License-Identifier: Apache 2.0 */
/* Copyright Contributors to the ODPi Egeria project. */
package org.odpi.openmetadata.adminservices.rest;

import java.io.Serializable;

/**
 * OMAGServerServiceType lists the different types of services supported by the OMAG Server
 */
public enum OMAGServerServiceType implements Serializable
{
    REPOSITORY_SERVICES  (0, "Repository Services", "The Open Metadata Repository Services (OMRS)."),
    ACCESS_SERVICES      (1, "Access Services",     "The Open Metadata Access Services (OMAS).");

    private static final long serialVersionUID = 1L;

    private int            typeCode;
    private String         typeName;
    private String         typeDescription;


    /**
     * Default Constructor
     *
     * @param typeCode ordinal for this enum
     * @param typeName symbolic name for this enum
     * @param typeDescription short description for this enum
     */
    OMAGServerServiceType(int     typeCode, String   typeName, String   typeDescription)
    {
        /*
         * Save the values supplied
         */
        this.typeCode = typeCode;
        this.typeName = typeName;
        this.typeDescription = typeDescription;
    }


    /**
     * Return the code for this enum instance
     *
     * @return int type code
     */
    public int getTypeCode()
    {
        return typeCode;
    }


    /**
     * Return the default name for this enum instance.
     *
     * @return String default name
     */
    public String getTypeName()
    {
        return typeName;
    }


    /**
     * Return the default description for the type for this enum instance.
     *
     * @return String default description
     */
    public String getTypeDescription()
    {
        return typeDescription;
    }
}
